@@ -22,6 +22,8 @@ import (
 	"github.com/jesseduffield/lazygit/pkg/gui/modes/cherrypicking"
 	"github.com/jesseduffield/lazygit/pkg/gui/modes/diffing"
 	"github.com/jesseduffield/lazygit/pkg/gui/modes/filtering"
+	"github.com/jesseduffield/lazygit/pkg/gui/presentation/authors"
+	"github.com/jesseduffield/lazygit/pkg/gui/presentation/graph"
 	"github.com/jesseduffield/lazygit/pkg/gui/style"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
 	"github.com/jesseduffield/lazygit/pkg/i18n"
@@ -144,9 +146,9 @@ type LblPanelState struct {
 type MergingPanelState struct {
 	*mergeconflicts.State
 
-	// UserScrolling tells us if the user has started scrolling through the file themselves
+	// UserVerticalScrolling tells us if the user has started scrolling through the file themselves
 	// in which case we won't auto-scroll to a conflict.
-	UserScrolling bool
+	UserVerticalScrolling bool
 }
 
 type filePanelState struct {
@@ -313,6 +315,8 @@ type guiState struct {
 	RetainOriginalDir bool
 	IsRefreshingFiles bool
 	Searching         searchingState
+	// if this is true, we'll load our commits using `git log --all`
+	ShowWholeGitGraph bool
 	ScreenMode        WindowMaximisation
 	Ptmx              *os.File
 	PrevMainWidth     int
@@ -394,7 +398,7 @@ func (gui *Gui) resetState(filterPath string, reuseState bool) {
 			Remotes:        &remotePanelState{listPanelState{SelectedLineIdx: 0}},
 			RemoteBranches: &remoteBranchesState{listPanelState{SelectedLineIdx: -1}},
 			Tags:           &tagsPanelState{listPanelState{SelectedLineIdx: -1}},
-			Commits:        &commitPanelState{listPanelState: listPanelState{SelectedLineIdx: -1}, LimitCommits: true},
+			Commits:        &commitPanelState{listPanelState: listPanelState{SelectedLineIdx: 0}, LimitCommits: true},
 			ReflogCommits:  &reflogCommitPanelState{listPanelState{SelectedLineIdx: 0}},
 			SubCommits:     &subCommitPanelState{listPanelState: listPanelState{SelectedLineIdx: 0}, refName: ""},
 			CommitFiles:    &commitFilesPanelState{listPanelState: listPanelState{SelectedLineIdx: -1}, refName: ""},
@@ -402,8 +406,8 @@ func (gui *Gui) resetState(filterPath string, reuseState bool) {
 			Menu:           &menuPanelState{listPanelState: listPanelState{SelectedLineIdx: 0}, OnPress: nil},
 			Suggestions:    &suggestionsPanelState{listPanelState: listPanelState{SelectedLineIdx: 0}},
 			Merging: &MergingPanelState{
-				State:         mergeconflicts.NewState(),
-				UserScrolling: false,
+				State:                 mergeconflicts.NewState(),
+				UserVerticalScrolling: false,
 			},
 		},
 		Ptmx: nil,
@@ -452,9 +456,17 @@ func NewGui(log *logrus.Entry, gitCommand *commands.GitCommand, oSCommand *oscom
 	oSCommand.SetOnRunCommand(onRunCommand)
 	gui.OnRunCommand = onRunCommand
 
+	authors.SetCustomAuthors(gui.Config.GetUserConfig().Gui.AuthorColors)
+
 	return gui, nil
 }
 
+var RuneReplacements = map[rune]string{
+	// for the commit graph
+	graph.MergeSymbol:  "M",
+	graph.CommitSymbol: "o",
+}
+
 // Run setup the gui with keybindings and start the mainloop
 func (gui *Gui) Run() error {
 	recordEvents := recordingEvents()
@@ -465,7 +477,7 @@ func (gui *Gui) Run() error {
 		playMode = gocui.REPLAYING
 	}
 
-	g, err := gocui.NewGui(gocui.OutputTrue, OverlappingEdges, playMode, headless())
+	g, err := gocui.NewGui(gocui.OutputTrue, OverlappingEdges, playMode, headless(), RuneReplacements)
 	if err != nil {
 		return err
 	}
@@ -709,6 +721,7 @@ func (gui *Gui) startBackgroundFetch() {
 	} else {
 		gui.goEvery(time.Second*time.Duration(userConfig.Refresher.FetchInterval), gui.stopChan, func() error {
 			err := gui.fetch(false, "")
+			gui.render()
 			return err
 		})
 	}
