@@ -202,8 +202,7 @@ func (gui *Gui) cleanString(s string) string {
 }
 
 func (gui *Gui) setViewContentSync(v *gocui.View, s string) {
-	v.Clear()
-	fmt.Fprint(v, gui.cleanString(s))
+	v.SetContent(gui.cleanString(s))
 }
 
 func (gui *Gui) setViewContent(v *gocui.View, s string) {
@@ -305,12 +304,13 @@ func (gui *Gui) refreshSelectedLine(panelState IListPanelState, total int) {
 }
 
 func (gui *Gui) renderDisplayStrings(v *gocui.View, displayStrings [][]string) {
-	gui.g.Update(func(g *gocui.Gui) error {
-		list := utils.RenderDisplayStrings(displayStrings)
-		v.Clear()
-		fmt.Fprint(v, list)
-		return nil
-	})
+	list := utils.RenderDisplayStrings(displayStrings)
+	v.SetContent(list)
+}
+
+func (gui *Gui) renderDisplayStringsAtPos(v *gocui.View, y int, displayStrings [][]string) {
+	list := utils.RenderDisplayStrings(displayStrings)
+	v.OverwriteLines(y, list)
 }
 
 func (gui *Gui) globalOptionsMap() map[string]string {
@@ -323,6 +323,7 @@ func (gui *Gui) globalOptionsMap() map[string]string {
 		gui.getKeyDisplay(keybindingConfig.Universal.Quit):       gui.Tr.LcQuit,
 		gui.getKeyDisplay(keybindingConfig.Universal.OptionMenu): gui.Tr.LcMenu,
 		fmt.Sprintf("%s-%s", gui.getKeyDisplay(keybindingConfig.Universal.JumpToBlock[0]), gui.getKeyDisplay(keybindingConfig.Universal.JumpToBlock[len(keybindingConfig.Universal.JumpToBlock)-1])): gui.Tr.LcJump,
+		fmt.Sprintf("%s/%s", gui.getKeyDisplay(keybindingConfig.Universal.ScrollLeft), gui.getKeyDisplay(keybindingConfig.Universal.ScrollRight)):                                                    gui.Tr.LcScrollLeftRight,
 	}
 }
 
@@ -388,3 +389,7 @@ func getTabbedView(gui *Gui) *gocui.View {
 	view, _ := gui.g.View(context.GetViewName())
 	return view
 }
+
+func (gui *Gui) render() {
+	gui.g.Update(func(g *gocui.Gui) error { return nil })
+}
